Creativity and motivation
-------------------------

While this book is not intended for professional programmers,
professional programming can be a very rewarding job both financially
and personally. Building useful, elegant, and clever programs for others
to use is a very creative activity. Your computer or Personal Digital
Assistant (PDA) usually contains many different programs from many
different groups of programmers, each competing for your attention and
interest. They try their best to meet your needs and give you a great
user experience in the process. In some situations, when you choose a
piece of software, the programmers are directly compensated because of
your choice.

If we think of programs as the creative output of groups of programmers,
perhaps the following figure is a more sensible version of our PDA:

.. figure:: Figures/pda2.svg
   :alt: Programmers Talking to You


For now, our primary motivation is not to make money or please end
users, but instead for us to be more productive in handling the data and
information that we will encounter in our lives. When you first start,
you will be both the programmer and the end user of your programs. As
you gain skill as a programmer and programming feels more creative to
you, your thoughts may turn toward developing programs for others.

.. mchoice:: intro-creativity-mc-intentions
    :answer_a: This book intended for professional programmers.
    :answer_b: This book is intended to create more productive programmers.
    :answer_c: This book is intended for computers with a single program.
    :answer_d: All of the above.
    :answer_e: None of the above.
    :correct: b
    :feedback_a: Try again. This book is not for professional programmers.
    :feedback_b: This book is for learning efficient and productive programming, especially when multiple programs are competing for your attention.
    :feedback_c: Try again.
    :feedback_d: Not quite. Only one of the above is true about this book.
    :feedback_e: One of the above is correct.

    Which of the following is true about this book?

.. mchoice:: intro-creativity-mc-tf
    :answer_a: True
    :answer_b: False
    :correct: a
    :feedback_a: You will be both writing programs and using them in this book.
    :feedback_b: Try again. You will be working on both sides.

    True or False? You will be both the programmer and the user in this book.

.. mchoice:: intro-creativity-mc-tf2
    :answer_a: True
    :answer_b: False
    :correct: b
    :feedback_a: Try again!
    :feedback_b: The primary motivation of this book is for us to be more productive in handling the data and information that we will encounter in our lives.


    True or False? The primary motivation of this book is to please end users and make money.
